# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class ConnectionStep(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"type": "str", "properties": "list[ConnectionStepProps]"}

    attribute_map = {"type": "type", "properties": "properties"}

    def __init__(
        self, type=None, properties=None, local_vars_configuration=None
    ):  # noqa: E501
        """ConnectionStep - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._properties = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if properties is not None:
            self.properties = properties

    @property
    def type(self):
        """Gets the type of this ConnectionStep.  # noqa: E501

        The type of step  # noqa: E501

        :return: The type of this ConnectionStep.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ConnectionStep.

        The type of step  # noqa: E501

        :param type: The type of this ConnectionStep.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "form",
            "oauth",
            "profile",
            "discover_schema",
            "field_selection",
            "fully_configured",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and type not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    @property
    def properties(self):
        """Gets the properties of this ConnectionStep.  # noqa: E501

        The destination connection type. For example: postgres or redshift   # noqa: E501

        :return: The properties of this ConnectionStep.  # noqa: E501
        :rtype: list[ConnectionStepProps]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this ConnectionStep.

        The destination connection type. For example: postgres or redshift   # noqa: E501

        :param properties: The properties of this ConnectionStep.  # noqa: E501
        :type: list[ConnectionStepProps]
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectionStep):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectionStep):
            return True

        return self.to_dict() != other.to_dict()
